@@ -77,6 +77,10 @@ typedef struct {
   SVC_SETUP_CALLBACK   svc_setup_callback;
   void                 (*associate_req_callback) (HANDLE lc_elan_handle,
                                                   int sizeoftlvs); /* LANE2 */
+  void                 (*proxy_arp_rsp_callback) (HANDLE lc_elan_handle,
+                                                  UINT8 *mac_addr, UINT32 tran_id,
+                                                  UINT16 lec_id, UINT8 *atm_addr);
+  void                (*topo_req_xmt_callback)(HANDLE lc_elan_handle, UINT32 flag);
   LA_ELAN_LIST         elan_list;
 } LA_CONTEXT;
 
@@ -141,11 +145,39 @@ kernel_associate_req_callback(struct atmlec_msg *mesg)
   }
 }
 
+static void
+kernel_proxy_arp_rsp_callback(struct atmlec_msg *mesg)
+{
+  LA_ELAN_CONTEXT *p_elan;
+
+  utl_list_traverse(lec_arp_context.elan_list, p_elan) {
+    lec_arp_context.proxy_arp_rsp_callback(p_elan->lc_elan_handle,
+                                           mesg->content.proxy.mac_addr,
+                                           mesg->content.proxy.tran_id,
+                                           mesg->content.proxy.lec_id,
+                                           mesg->content.proxy.atm_addr);
+  }
+}
+
+static void
+kernel_topo_req_xmt_callback(struct atmlec_msg *mesg)
+{
+  LA_ELAN_CONTEXT *p_elan;
+
+  utl_list_traverse(lec_arp_context.elan_list, p_elan) {
+    lec_arp_context.topo_req_xmt_callback(p_elan->lc_elan_handle,
+                                           mesg->content.normal.flag);
+  }
+}
+
 STATUS 
 la_create (HANDLE lc_handle, ARP_XMT_CALLBACK arp_xmt_callback,
 	   FLUSH_XMT_CALLBACK flush_xmt_callback,
 	   SVC_SETUP_CALLBACK svc_setup_callback,
            void (*associate_req_callback)(HANDLE lc_elan_handle, int sizeoftlvs), /* LANE2 */
+           void (*proxy_arp_rsp_callback)(HANDLE lc_elan_handle, UINT8 *mac_addr,
+                                          UINT32 tran_id, UINT16 lec_id, UINT8 *atm_addr),
+           void (*topo_req_xmt_callback)(HANDLE lc_elan_handle, UINT32 flag),
 	   HANDLE *p_la_handle)
 {
   lec_arp_context.lc_handle = lc_handle;
@@ -153,12 +185,16 @@ la_create (HANDLE lc_handle, ARP_XMT_CALLBACK arp_xmt_callback,
   lec_arp_context.flush_xmt_callback  = flush_xmt_callback;
   lec_arp_context.svc_setup_callback  = svc_setup_callback;
   lec_arp_context.associate_req_callback = associate_req_callback; /* LANE2 */
+  lec_arp_context.proxy_arp_rsp_callback = proxy_arp_rsp_callback;
+  lec_arp_context.topo_req_xmt_callback = topo_req_xmt_callback;
   
   utl_list_init(lec_arp_context.elan_list);
 
   kernel_register_callback(l_arp_xmt, kernel_arp_xmt_callback);
   kernel_register_callback(l_svc_setup, kernel_svc_setup_xmt_callback);
   kernel_register_callback(l_associate_req, kernel_associate_req_callback);
+  kernel_register_callback(l_should_bridge, kernel_proxy_arp_rsp_callback);
+  kernel_register_callback(l_topology_change, kernel_topo_req_xmt_callback);
 
   *p_la_handle = (HANDLE)&lec_arp_context;
 
@@ -249,6 +285,7 @@ la_config(HANDLE la_elan_handle, LAN_TYPE lan_type,
   conf_mesg.flush_timeout = flush_timeout;
   conf_mesg.path_switching_delay = path_switching_delay;
   conf_mesg.lane_version = lane_version_number; /* LANE2 */
+  conf_mesg.is_proxy = (proxy_flag == TRUE) ? 1 : 0;
   kernel_sendmsg(l_config, NULL, NULL, &conf_mesg, 0, NULL, 0, 0, 0);
 }
 
