@@ -1,6 +1,6 @@
 /* qosequal.c - Compares QOS specifications for equality */
 
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1999 by Werner Almesberger, EPFL-LRC */
 
 
 #include "atm.h"
@@ -21,7 +21,8 @@ static int tp_equal(int traffic_class,struct atm_trafprm a,struct atm_trafprm b)
     }
     if (!a.max_pcr && !a.min_pcr) a.max_pcr = ATM_MAX_PCR;
     if (!b.max_pcr && !b.min_pcr) b.max_pcr = ATM_MAX_PCR;
-    if (a.max_pcr != b.max_pcr || a.min_pcr != b.min_pcr) return 0;
+    if (a.max_pcr != b.max_pcr || a.pcr != b.pcr || a.min_pcr != b.min_pcr)
+	return 0;
     return a.max_sdu == b.max_sdu;
 }
 
