@@ -1,6 +1,6 @@
 /* zntune.c - ZN122x free buffer pool tuning */
  
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -9,7 +9,7 @@
 #include <errno.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
-#include <linux/atm.h>
+#include <atm.h>
 #include <sys/time.h> /* for struct timeval, although it's not used */
 #include <linux/atm_zatm.h>
 
