@@ -200,7 +200,7 @@ static void dump_trace(FILE *file,const char *banner)
 
 void poll_signals(void)
 {
-    static status_num = 0,trace_num = 0;
+    static int status_num = 0,trace_num = 0;
     char path[PATH_MAX+1];
     FILE *file;
 
